@@ -2,7 +2,7 @@
 
 #
 #   Developer : Alexey Zakharov (alexey.zakharov@vectioneer.com)
-#   All rights reserved. Copyright (c) 2016 VECTIONEER.
+#   All rights reserved. Copyright (c) 2016 - 2024 VECTIONEER.
 #
 
 from motorcortex.version import __version__
@@ -14,14 +14,22 @@ from motorcortex.subscribe import Subscribe
 from motorcortex.subscription import Subscription
 from motorcortex.setup_logger import logger
 
-
 def parseUrl(url):
     end = url.rfind(':')
     start = url.rfind(':', 0, end)
+    if end == -1 or start == -1:
+        return url + '/mcx_req', url + '/mcx_sub', None, None
     req_port = int(url[start + 1:end])
     sub_port = int(url[end + 1:])
     address = url[:start]
-    return address, req_port, sub_port
+    return address, address, req_port, sub_port
+
+
+def makeUrl(address, port):
+    if port:
+        return "{}:{}".format(address, port)
+
+    return address
 
 
 def connect(url, motorcortex_types, param_tree, reconnect=True, **kwargs):
@@ -34,17 +42,17 @@ def connect(url, motorcortex_types, param_tree, reconnect=True, **kwargs):
         kwargs.update(state_update=stateUpdate)
 
     # Parse address
-    address, req_port, sub_port = parseUrl(url)
+    req_address, sub_address, req_port, sub_port = parseUrl(url)
     # Open request connection
     req = Request(motorcortex_types, param_tree)
     kwargs_copy = kwargs.copy()
     kwargs_copy.update(state_update=None)
-    if not req.connect("{}:{}".format(address, req_port), **kwargs_copy).get():
-        raise RuntimeError("Failed to establish request connection: {}:{}".format(address, req_port))
+    if not req.connect(makeUrl(req_address, req_port), **kwargs_copy).get():
+        raise RuntimeError("Failed to establish request connection: {}:{}".format(req_address, req_port))
     # Open subscribe connection
     sub = Subscribe(req, motorcortex_types)
-    if not sub.connect("{}:{}".format(address, sub_port), **kwargs).get():
-        raise RuntimeError("Failed to establish subscribe connection: {}:{}".format(address, sub_port))
+    if not sub.connect(makeUrl(sub_address, sub_port), **kwargs).get():
+        raise RuntimeError("Failed to establish subscribe connection: {}:{}".format(sub_address, sub_port))
     # Login
     login_reply = req.login(kwargs['login'], kwargs['password'])
     login_reply_msg = login_reply.get()
