@@ -93,7 +93,7 @@ class Request(object):
 
         self.__socket.add_post_pipe_connect_cb(pre_connect_cb)
         self.__socket.add_post_pipe_remove_cb(post_remove_cb)
-        self.__socket.dial(url)
+        self.__socket.dial(url, block=False)
 
         return Reply(self.__pool.submit(self.waitForConnection, self.__connected_lock,
                                         conn_timeout_ms / 1000.0))
@@ -276,7 +276,7 @@ class Request(object):
         """Get description and values of requested parameters.
 
             Args:
-                path_list(str): list of parameter paths in the tree.
+                path_list(list(str)): list of parameter paths in the tree.
 
             Returns:
                 Reply(ParameterListMsg): A Promise, which resolves when list of the parameter values is received, fails
@@ -490,7 +490,7 @@ class Request(object):
             if protobuf_types:
                 return protobuf_types.decode(buffer)
             else:
-                return protobuf_types
+                return buffer
 
         return None
 
